# IMPORTATION STANDARD
import logging
from typing import Dict, Union

# IMPORTATION THIRD PARTY
import requests
from google.protobuf import json_format

# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.core.abstracts.abstract_action import AbstractAction
from degiro_connector.trading.models.trading_pb2 import Credentials, EstimatesSummaries


class ActionGetEstimatesSummaries(AbstractAction):
    @staticmethod
    def estimates_summaries_to_grpc(payload: dict) -> EstimatesSummaries:
        estimates_summaries = EstimatesSummaries()
        json_format.ParseDict(
            js_dict=payload["data"],
            message=estimates_summaries,
            ignore_unknown_fields=False,
            descriptor_pool=None,
        )
        return estimates_summaries

    @classmethod
    def get_estimates_summaries(
        cls,
        product_isin: str,
        session_id: str,
        credentials: Credentials,
        raw: bool = False,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> Union[EstimatesSummaries, Dict, None]:
        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        int_account = credentials.int_account
        url = f"{urls.ESTIMATES_SUMMARIES}/{product_isin}"

        params = {
            "intAccount": int_account,
            "sessionId": session_id,
        }

        request = requests.Request(method="GET", url=url, params=params)
        prepped = session.prepare_request(request)
        prepped.headers["cookie"] = "JSESSIONID=" + session_id

        response_raw = None

        try:
            response_raw = session.send(prepped, verify=False)
            response_raw.raise_for_status()
            response_dict = response_raw.json()

            if raw is True:
                return response_dict
            else:
                return cls.estimates_summaries_to_grpc(
                    payload=response_dict,
                )
        except Exception as e:
            logger.fatal("error")
            logger.fatal(response_raw)
            logger.fatal(e)
            return None

    def call(
        self,
        product_isin: str,
        raw: bool = False,
    ) -> Union[EstimatesSummaries, Dict, None]:
        connection_storage = self.connection_storage
        session_id = connection_storage.session_id
        session = self.session_storage.session
        credentials = self.credentials
        logger = self.logger

        return self.get_estimates_summaries(
            product_isin=product_isin,
            session_id=session_id,
            credentials=credentials,
            raw=raw,
            session=session,
            logger=logger,
        )



import os
import re

from typing import List


""" Migrate from 0.1.3 to 1.0.0.

This script will do the following changes :
- Replace `quotecast` module with `degiro_connector.quotecast`
- Replace `trading` module with `degiro_connector.trading`

If files might require manual update it will list those files.
"""


def need_manual_update(file_source: str) -> bool:
    x = re.search(
        pattern=r"(quotecast|trading)\s*=\s*[A-Z]",
        string=file_source,
    )

    return x is not None


def get_files_list(root_path=".") -> List[str]:
    files_list = list()

    for root, directories, files in os.walk(root_path):
        for name in files:
            if (
                name.endswith(".py")
                and ".tox" not in root
                and ".git" not in root
                and ".egg-info" not in root
                and "\\build\\lib" not in root
                and not name.endswith("setup.py")
            ):
                files_list.append(os.path.join(root, name))

    return files_list


def process(files_list: List[str]):
    manual_update_list = list()

    print("Processing the following files : ")

    for file_path in files_list:
        if os.path.realpath(file_path) != os.path.realpath(__file__):
            with open(file_path, "r+") as f:
                file_source = f.read()
                replace_string = file_source
                replace_string = replace_string.replace(
                    " quotecast.",
                    " degiro_connector.quotecast.",
                )
                replace_string = replace_string.replace(
                    " trading.",
                    " degiro_connector.trading.",
                )

                if need_manual_update(file_source):
                    print("UNCHANGED :", file_path)
                    manual_update_list.append(file_path)
                elif replace_string != file_source:
                    print("CHANGED   :", file_path)
                    f.seek(0)
                    f.write(replace_string)
                    f.truncate()
                else:
                    print("UNCHANGED :", file_path)

    if len(manual_update_list) > 0:
        print("The following files might need a manual update :")
        for file_path in manual_update_list:
            print(file_path)


files_list = get_files_list(root_path=".")
process(files_list=files_list)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Credentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INT_ACCOUNT_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    TOTP_SECRET_KEY_FIELD_NUMBER: builtins.int
    ONE_TIME_PASSWORD_FIELD_NUMBER: builtins.int
    int_account: builtins.int = ...
    username: typing.Text = ...
    password: typing.Text = ...
    totp_secret_key: typing.Text = ...
    one_time_password: builtins.int = ...
    def __init__(self,
        *,
        int_account : builtins.int = ...,
        username : typing.Text = ...,
        password : typing.Text = ...,
        totp_secret_key : typing.Text = ...,
        one_time_password : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"one_time_password",b"one_time_password",u"oneof_2fa",b"oneof_2fa",u"totp_secret_key",b"totp_secret_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"int_account",b"int_account",u"one_time_password",b"one_time_password",u"oneof_2fa",b"oneof_2fa",u"password",b"password",u"totp_secret_key",b"totp_secret_key",u"username",b"username"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"oneof_2fa",b"oneof_2fa"]) -> typing.Optional[typing_extensions.Literal["totp_secret_key","one_time_password"]]: ...
global___Credentials = Credentials

class Order(google.protobuf.message.Message):
    """* For the payload from the following URLs :
    https://trader.degiro.nl/trading/secure/v5/checkOrder
    https://trader.degiro.nl/trading/secure/v5/order
    https://trader.degiro.nl/reporting/secure/v4/order-history
    https://trader.degiro.nl/trading/secure/v5/update
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Action(_Action, metaclass=_ActionEnumTypeWrapper):
        """ENUMS"""
        pass
    class _Action:
        V = typing.NewType('V', builtins.int)
    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Action.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        BUY = Order.Action.V(0)
        SELL = Order.Action.V(1)

    BUY = Order.Action.V(0)
    SELL = Order.Action.V(1)

    class OrderType(_OrderType, metaclass=_OrderTypeEnumTypeWrapper):
        pass
    class _OrderType:
        V = typing.NewType('V', builtins.int)
    class _OrderTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OrderType.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        LIMIT = Order.OrderType.V(0)
        STOP_LIMIT = Order.OrderType.V(1)
        MARKET = Order.OrderType.V(2)
        STOP_LOSS = Order.OrderType.V(3)
        """*
        LIMIT_HIT = ?;
        TRAILING_STOP = ?;
        JOIN = ?;
        STANDARD_SIZE = ?;
        STANDARD_AMOUNT = ?;
        TAKE_PROFIT = ?;
        COMBINED = ?;
        OCO = ?;
        """


    LIMIT = Order.OrderType.V(0)
    STOP_LIMIT = Order.OrderType.V(1)
    MARKET = Order.OrderType.V(2)
    STOP_LOSS = Order.OrderType.V(3)
    """*
    LIMIT_HIT = ?;
    TRAILING_STOP = ?;
    JOIN = ?;
    STANDARD_SIZE = ?;
    STANDARD_AMOUNT = ?;
    TAKE_PROFIT = ?;
    COMBINED = ?;
    OCO = ?;
    """


    class TimeType(_TimeType, metaclass=_TimeTypeEnumTypeWrapper):
        pass
    class _TimeType:
        V = typing.NewType('V', builtins.int)
    class _TimeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TimeType.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNKNOWN_0 = Order.TimeType.V(0)
        GOOD_TILL_DAY = Order.TimeType.V(1)
        UNKNOWN_2 = Order.TimeType.V(2)
        GOOD_TILL_CANCELED = Order.TimeType.V(3)

    UNKNOWN_0 = Order.TimeType.V(0)
    GOOD_TILL_DAY = Order.TimeType.V(1)
    UNKNOWN_2 = Order.TimeType.V(2)
    GOOD_TILL_CANCELED = Order.TimeType.V(3)

    class CheckingResponse(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONFIRMATION_ID_FIELD_NUMBER: builtins.int
        FREE_SPACE_NEW_FIELD_NUMBER: builtins.int
        RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
        TRANSACTION_FEES_FIELD_NUMBER: builtins.int
        TRANSACTION_OPPOSITE_FEES_FIELD_NUMBER: builtins.int
        TRANSACTION_TAXES_FIELD_NUMBER: builtins.int
        TRANSACTION_AUTO_FX_SURCHARGES_FIELD_NUMBER: builtins.int
        TRANSACTION_AUTO_FX_OPPOSITE_SURCHARGES_FIELD_NUMBER: builtins.int
        AUTO_FX_CONVERSION_RATE_FIELD_NUMBER: builtins.int
        TRANSACTION_FEE_FIELD_NUMBER: builtins.int
        SHOW_EX_ANTE_REPORT_LINK_FIELD_NUMBER: builtins.int
        confirmation_id: typing.Text = ...
        free_space_new: builtins.float = ...
        @property
        def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        @property
        def transaction_fees(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
        @property
        def transaction_opposite_fees(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
        @property
        def transaction_taxes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
        @property
        def transaction_auto_fx_surcharges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
        @property
        def transaction_auto_fx_opposite_surcharges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
        auto_fx_conversion_rate: builtins.float = ...
        transaction_fee: builtins.float = ...
        show_ex_ante_report_link: builtins.bool = ...
        def __init__(self,
            *,
            confirmation_id : typing.Text = ...,
            free_space_new : builtins.float = ...,
            response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
            transaction_fees : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
            transaction_opposite_fees : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
            transaction_taxes : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
            transaction_auto_fx_surcharges : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
            transaction_auto_fx_opposite_surcharges : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
            auto_fx_conversion_rate : builtins.float = ...,
            transaction_fee : builtins.float = ...,
            show_ex_ante_report_link : builtins.bool = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"auto_fx_conversion_rate",b"auto_fx_conversion_rate",u"confirmation_id",b"confirmation_id",u"free_space_new",b"free_space_new",u"response_datetime",b"response_datetime",u"show_ex_ante_report_link",b"show_ex_ante_report_link",u"transaction_auto_fx_opposite_surcharges",b"transaction_auto_fx_opposite_surcharges",u"transaction_auto_fx_surcharges",b"transaction_auto_fx_surcharges",u"transaction_fee",b"transaction_fee",u"transaction_fees",b"transaction_fees",u"transaction_opposite_fees",b"transaction_opposite_fees",u"transaction_taxes",b"transaction_taxes"]) -> None: ...

    class ConfirmationResponse(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ORDER_ID_FIELD_NUMBER: builtins.int
        RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
        order_id: typing.Text = ...
        @property
        def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(self,
            *,
            order_id : typing.Text = ...,
            response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"order_id",b"order_id",u"response_datetime",b"response_datetime"]) -> None: ...

    ACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ORDER_TYPE_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    STOP_PRICE_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TIME_TYPE_FIELD_NUMBER: builtins.int
    CONTRACT_SIZE_FIELD_NUMBER: builtins.int
    CONTRACT_TYPE_FIELD_NUMBER: builtins.int
    CURRENCY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    IS_DELETABLE_FIELD_NUMBER: builtins.int
    IS_MODIFIABLE_FIELD_NUMBER: builtins.int
    PRODUCT_FIELD_NUMBER: builtins.int
    QUANTITY_FIELD_NUMBER: builtins.int
    TOTAL_ORDER_VALUE_FIELD_NUMBER: builtins.int
    RETAINED_ORDER_FIELD_NUMBER: builtins.int
    SENT_TO_EXCHANGE_FIELD_NUMBER: builtins.int
    action: global___Order.Action.V = ...
    """USED TO CHECK ORDER
    called "buysell" by the API
    """

    id: typing.Text = ...
    order_type: global___Order.OrderType.V = ...
    """called "orderTypeId" by the API"""

    price: builtins.float = ...
    stop_price: builtins.float = ...
    """called "stopPrice" by the API"""

    product_id: builtins.int = ...
    """called "productId" by the API"""

    size: builtins.float = ...
    time_type: global___Order.TimeType.V = ...
    """called "orderTimeTypeId" by the API"""

    contract_size: builtins.float = ...
    """USED TO CONFIRM ORDER
    called "contractSize" by the API
    """

    contract_type: builtins.int = ...
    """called "contractType" by the API"""

    currency: typing.Text = ...
    hour: typing.Text = ...
    """called "date" by the API"""

    is_deletable: builtins.bool = ...
    """contains %H:%M if the date was not passed
    called "isDeletable" by the API
    """

    is_modifiable: builtins.bool = ...
    """called "isModifiable" by the API"""

    product: typing.Text = ...
    quantity: builtins.float = ...
    total_order_value: builtins.float = ...
    """called "totalOrderValue" by the API"""

    retained_order: builtins.bool = ...
    """USED FOR ORDERS HISTORY
    called "retainedOrder" by the API
    """

    sent_to_exchange: builtins.bool = ...
    """called "sentToExchange" by the API"""

    def __init__(self,
        *,
        action : global___Order.Action.V = ...,
        id : typing.Text = ...,
        order_type : global___Order.OrderType.V = ...,
        price : builtins.float = ...,
        stop_price : builtins.float = ...,
        product_id : builtins.int = ...,
        size : builtins.float = ...,
        time_type : global___Order.TimeType.V = ...,
        contract_size : builtins.float = ...,
        contract_type : builtins.int = ...,
        currency : typing.Text = ...,
        hour : typing.Text = ...,
        is_deletable : builtins.bool = ...,
        is_modifiable : builtins.bool = ...,
        product : typing.Text = ...,
        quantity : builtins.float = ...,
        total_order_value : builtins.float = ...,
        retained_order : builtins.bool = ...,
        sent_to_exchange : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"action",b"action",u"contract_size",b"contract_size",u"contract_type",b"contract_type",u"currency",b"currency",u"hour",b"hour",u"id",b"id",u"is_deletable",b"is_deletable",u"is_modifiable",b"is_modifiable",u"order_type",b"order_type",u"price",b"price",u"product",b"product",u"product_id",b"product_id",u"quantity",b"quantity",u"retained_order",b"retained_order",u"sent_to_exchange",b"sent_to_exchange",u"size",b"size",u"stop_price",b"stop_price",u"time_type",b"time_type",u"total_order_value",b"total_order_value"]) -> None: ...
global___Order = Order

class Update(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/trading/secure/v5/update
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Option(_Option, metaclass=_OptionEnumTypeWrapper):
        """ENUMS"""
        pass
    class _Option:
        V = typing.NewType('V', builtins.int)
    class _OptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Option.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        ALERTS = Update.Option.V(0)
        CASHFUNDS = Update.Option.V(1)
        HISTORICALORDERS = Update.Option.V(2)
        ORDERS = Update.Option.V(3)
        PORTFOLIO = Update.Option.V(4)
        TOTALPORTFOLIO = Update.Option.V(5)
        TRANSACTIONS = Update.Option.V(6)

    ALERTS = Update.Option.V(0)
    CASHFUNDS = Update.Option.V(1)
    HISTORICALORDERS = Update.Option.V(2)
    ORDERS = Update.Option.V(3)
    PORTFOLIO = Update.Option.V(4)
    TOTALPORTFOLIO = Update.Option.V(5)
    TRANSACTIONS = Update.Option.V(6)

    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        OPTION_FIELD_NUMBER: builtins.int
        LAST_UPDATED_FIELD_NUMBER: builtins.int
        option: global___Update.Option.V = ...
        last_updated: builtins.int = ...
        def __init__(self,
            *,
            option : global___Update.Option.V = ...,
            last_updated : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"last_updated",b"last_updated",u"option",b"option"]) -> None: ...

    class RequestList(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        VALUES_FIELD_NUMBER: builtins.int
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Update.Request]: ...
        def __init__(self,
            *,
            values : typing.Optional[typing.Iterable[global___Update.Request]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> None: ...

    class Alerts(google.protobuf.message.Message):
        """MESSAGES FOR PROPERTIES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LAST_UPDATED_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        last_updated: builtins.int = ...
        @property
        def values(self) -> google.protobuf.struct_pb2.Struct: ...
        def __init__(self,
            *,
            last_updated : builtins.int = ...,
            values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"last_updated",b"last_updated",u"values",b"values"]) -> None: ...

    class CashFunds(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LAST_UPDATED_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        last_updated: builtins.int = ...
        @property
        def values(self) -> google.protobuf.struct_pb2.Struct: ...
        def __init__(self,
            *,
            last_updated : builtins.int = ...,
            values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"last_updated",b"last_updated",u"values",b"values"]) -> None: ...

    class HistoricalOrders(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LAST_UPDATED_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        last_updated: builtins.int = ...
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Order]: ...
        def __init__(self,
            *,
            last_updated : builtins.int = ...,
            values : typing.Optional[typing.Iterable[global___Order]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"last_updated",b"last_updated",u"values",b"values"]) -> None: ...

    class Orders(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LAST_UPDATED_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        last_updated: builtins.int = ...
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Order]:
            """Order"""
            pass
        def __init__(self,
            *,
            last_updated : builtins.int = ...,
            values : typing.Optional[typing.Iterable[global___Order]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"last_updated",b"last_updated",u"values",b"values"]) -> None: ...

    class Portfolio(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LAST_UPDATED_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        last_updated: builtins.int = ...
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
            """positionrow"""
            pass
        def __init__(self,
            *,
            last_updated : builtins.int = ...,
            values : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"last_updated",b"last_updated",u"values",b"values"]) -> None: ...

    class TotalPortfolio(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LAST_UPDATED_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        last_updated: builtins.int = ...
        @property
        def values(self) -> google.protobuf.struct_pb2.Struct: ...
        def __init__(self,
            *,
            last_updated : builtins.int = ...,
            values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"last_updated",b"last_updated",u"values",b"values"]) -> None: ...

    class Transactions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LAST_UPDATED_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        last_updated: builtins.int = ...
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
            """Transaction"""
            pass
        def __init__(self,
            *,
            last_updated : builtins.int = ...,
            values : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"last_updated",b"last_updated",u"values",b"values"]) -> None: ...

    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    ALERTS_FIELD_NUMBER: builtins.int
    CASH_FUNDS_FIELD_NUMBER: builtins.int
    HISTORICAL_ORDERS_FIELD_NUMBER: builtins.int
    ORDERS_FIELD_NUMBER: builtins.int
    PORTFOLIO_FIELD_NUMBER: builtins.int
    TOTAL_PORTFOLIO_FIELD_NUMBER: builtins.int
    TRANSACTIONS_FIELD_NUMBER: builtins.int
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """PROPERTIES"""
        pass
    @property
    def alerts(self) -> global___Update.Alerts: ...
    @property
    def cash_funds(self) -> global___Update.CashFunds: ...
    @property
    def historical_orders(self) -> global___Update.HistoricalOrders: ...
    @property
    def orders(self) -> global___Update.Orders: ...
    @property
    def portfolio(self) -> global___Update.Portfolio: ...
    @property
    def total_portfolio(self) -> global___Update.TotalPortfolio: ...
    @property
    def transactions(self) -> global___Update.Transactions: ...
    def __init__(self,
        *,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        alerts : typing.Optional[global___Update.Alerts] = ...,
        cash_funds : typing.Optional[global___Update.CashFunds] = ...,
        historical_orders : typing.Optional[global___Update.HistoricalOrders] = ...,
        orders : typing.Optional[global___Update.Orders] = ...,
        portfolio : typing.Optional[global___Update.Portfolio] = ...,
        total_portfolio : typing.Optional[global___Update.TotalPortfolio] = ...,
        transactions : typing.Optional[global___Update.Transactions] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"alerts",b"alerts",u"cash_funds",b"cash_funds",u"historical_orders",b"historical_orders",u"orders",b"orders",u"portfolio",b"portfolio",u"response_datetime",b"response_datetime",u"total_portfolio",b"total_portfolio",u"transactions",b"transactions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"alerts",b"alerts",u"cash_funds",b"cash_funds",u"historical_orders",b"historical_orders",u"orders",b"orders",u"portfolio",b"portfolio",u"response_datetime",b"response_datetime",u"total_portfolio",b"total_portfolio",u"transactions",b"transactions"]) -> None: ...
global___Update = Update

class OrdersHistory(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/reporting/secure/v4/order-history
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Date(google.protobuf.message.Message):
            """MESSAGES"""
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            YEAR_FIELD_NUMBER: builtins.int
            MONTH_FIELD_NUMBER: builtins.int
            DAY_FIELD_NUMBER: builtins.int
            year: builtins.int = ...
            month: builtins.int = ...
            day: builtins.int = ...
            def __init__(self,
                *,
                year : builtins.int = ...,
                month : builtins.int = ...,
                day : builtins.int = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"day",b"day",u"month",b"month",u"year",b"year"]) -> None: ...

        FROM_DATE_FIELD_NUMBER: builtins.int
        TO_DATE_FIELD_NUMBER: builtins.int
        @property
        def from_date(self) -> global___OrdersHistory.Request.Date:
            """PROPERTIES"""
            pass
        @property
        def to_date(self) -> global___OrdersHistory.Request.Date: ...
        def __init__(self,
            *,
            from_date : typing.Optional[global___OrdersHistory.Request.Date] = ...,
            to_date : typing.Optional[global___OrdersHistory.Request.Date] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"from_date",b"from_date",u"to_date",b"to_date"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"from_date",b"from_date",u"to_date",b"to_date"]) -> None: ...

    VALUES_FIELD_NUMBER: builtins.int
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """PROPERTIES"""
        pass
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        values : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime",u"values",b"values"]) -> None: ...
global___OrdersHistory = OrdersHistory

class TransactionsHistory(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/reporting/secure/v4/transactions
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Date(google.protobuf.message.Message):
            """MESSAGES"""
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            YEAR_FIELD_NUMBER: builtins.int
            MONTH_FIELD_NUMBER: builtins.int
            DAY_FIELD_NUMBER: builtins.int
            year: builtins.int = ...
            month: builtins.int = ...
            day: builtins.int = ...
            def __init__(self,
                *,
                year : builtins.int = ...,
                month : builtins.int = ...,
                day : builtins.int = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"day",b"day",u"month",b"month",u"year",b"year"]) -> None: ...

        FROM_DATE_FIELD_NUMBER: builtins.int
        TO_DATE_FIELD_NUMBER: builtins.int
        GROUP_TRANSACTIONS_BY_ORDER_FIELD_NUMBER: builtins.int
        @property
        def from_date(self) -> global___TransactionsHistory.Request.Date:
            """PROPERTIES"""
            pass
        @property
        def to_date(self) -> global___TransactionsHistory.Request.Date: ...
        group_transactions_by_order: builtins.bool = ...
        def __init__(self,
            *,
            from_date : typing.Optional[global___TransactionsHistory.Request.Date] = ...,
            to_date : typing.Optional[global___TransactionsHistory.Request.Date] = ...,
            group_transactions_by_order : builtins.bool = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"from_date",b"from_date",u"to_date",b"to_date"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"from_date",b"from_date",u"group_transactions_by_order",b"group_transactions_by_order",u"to_date",b"to_date"]) -> None: ...

    VALUES_FIELD_NUMBER: builtins.int
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """PROPERTIES"""
        pass
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        values : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime",u"values",b"values"]) -> None: ...
global___TransactionsHistory = TransactionsHistory

class AccountOverview(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/reporting/secure/v6/accountoverview
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Date(google.protobuf.message.Message):
            """MESSAGES"""
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            YEAR_FIELD_NUMBER: builtins.int
            MONTH_FIELD_NUMBER: builtins.int
            DAY_FIELD_NUMBER: builtins.int
            year: builtins.int = ...
            month: builtins.int = ...
            day: builtins.int = ...
            def __init__(self,
                *,
                year : builtins.int = ...,
                month : builtins.int = ...,
                day : builtins.int = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"day",b"day",u"month",b"month",u"year",b"year"]) -> None: ...

        FROM_DATE_FIELD_NUMBER: builtins.int
        TO_DATE_FIELD_NUMBER: builtins.int
        @property
        def from_date(self) -> global___AccountOverview.Request.Date:
            """PROPERTIES"""
            pass
        @property
        def to_date(self) -> global___AccountOverview.Request.Date: ...
        def __init__(self,
            *,
            from_date : typing.Optional[global___AccountOverview.Request.Date] = ...,
            to_date : typing.Optional[global___AccountOverview.Request.Date] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"from_date",b"from_date",u"to_date",b"to_date"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"from_date",b"from_date",u"to_date",b"to_date"]) -> None: ...

    VALUES_FIELD_NUMBER: builtins.int
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.struct_pb2.Struct:
        """PROPERTIES"""
        pass
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime",u"values",b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime",u"values",b"values"]) -> None: ...
global___AccountOverview = AccountOverview

class ProductSearch(google.protobuf.message.Message):
    """* For the payload from the following URLs :
    https://trader.degiro.nl/product_search/secure/v5/bonds
    https://trader.degiro.nl/product_search/secure/v5/etfs
    https://trader.degiro.nl/product_search/secure/v5/funds
    https://trader.degiro.nl/product_search/secure/v5/futures
    https://trader.degiro.nl/product_search/secure/v5/leverageds
    https://trader.degiro.nl/product_search/secure/v5/lookup
    https://trader.degiro.nl/product_search/secure/v5/options
    https://trader.degiro.nl/product_search/secure/v5/stocks
    https://trader.degiro.nl/product_search/secure/v5/warrants
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Config(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        VALUES_FIELD_NUMBER: builtins.int
        @property
        def values(self) -> google.protobuf.struct_pb2.Struct: ...
        def __init__(self,
            *,
            values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> None: ...

    class RequestBonds(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        BOND_ISSUER_TYPE_ID_FIELD_NUMBER: builtins.int
        BOND_EXCHANGE_ID_FIELD_NUMBER: builtins.int
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        REQUIRE_TOTAL_FIELD_NUMBER: builtins.int
        SORT_COLUMNS_FIELD_NUMBER: builtins.int
        SORT_TYPES_FIELD_NUMBER: builtins.int
        bond_issuer_type_id: builtins.int = ...
        bond_exchange_id: builtins.int = ...
        search_text: typing.Text = ...
        offset: builtins.int = ...
        limit: builtins.int = ...
        require_total: builtins.bool = ...
        sort_columns: typing.Text = ...
        sort_types: typing.Text = ...
        def __init__(self,
            *,
            bond_issuer_type_id : builtins.int = ...,
            bond_exchange_id : builtins.int = ...,
            search_text : typing.Text = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            require_total : builtins.bool = ...,
            sort_columns : typing.Text = ...,
            sort_types : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"bond_exchange_id",b"bond_exchange_id",u"bond_issuer_type_id",b"bond_issuer_type_id",u"limit",b"limit",u"offset",b"offset",u"require_total",b"require_total",u"search_text",b"search_text",u"sort_columns",b"sort_columns",u"sort_types",b"sort_types"]) -> None: ...

    class RequestETFs(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        POPULAR_ONLY_FIELD_NUMBER: builtins.int
        INPUT_AGGREGATE_TYPES_FIELD_NUMBER: builtins.int
        INPUT_AGGREGATE_VALUES_FIELD_NUMBER: builtins.int
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        REQUIRE_TOTAL_FIELD_NUMBER: builtins.int
        SORT_COLUMNS_FIELD_NUMBER: builtins.int
        SORT_TYPES_FIELD_NUMBER: builtins.int
        popular_only: builtins.bool = ...
        input_aggregate_types: typing.Text = ...
        input_aggregate_values: typing.Text = ...
        search_text: typing.Text = ...
        offset: builtins.int = ...
        limit: builtins.int = ...
        require_total: builtins.bool = ...
        sort_columns: typing.Text = ...
        sort_types: typing.Text = ...
        def __init__(self,
            *,
            popular_only : builtins.bool = ...,
            input_aggregate_types : typing.Text = ...,
            input_aggregate_values : typing.Text = ...,
            search_text : typing.Text = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            require_total : builtins.bool = ...,
            sort_columns : typing.Text = ...,
            sort_types : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"input_aggregate_types",b"input_aggregate_types",u"input_aggregate_values",b"input_aggregate_values",u"limit",b"limit",u"offset",b"offset",u"popular_only",b"popular_only",u"require_total",b"require_total",u"search_text",b"search_text",u"sort_columns",b"sort_columns",u"sort_types",b"sort_types"]) -> None: ...

    class RequestFunds(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        REQUIRE_TOTAL_FIELD_NUMBER: builtins.int
        SORT_COLUMNS_FIELD_NUMBER: builtins.int
        SORT_TYPES_FIELD_NUMBER: builtins.int
        search_text: typing.Text = ...
        offset: builtins.int = ...
        limit: builtins.int = ...
        require_total: builtins.bool = ...
        sort_columns: typing.Text = ...
        sort_types: typing.Text = ...
        def __init__(self,
            *,
            search_text : typing.Text = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            require_total : builtins.bool = ...,
            sort_columns : typing.Text = ...,
            sort_types : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"limit",b"limit",u"offset",b"offset",u"require_total",b"require_total",u"search_text",b"search_text",u"sort_columns",b"sort_columns",u"sort_types",b"sort_types"]) -> None: ...

    class RequestFutures(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FUTURE_EXCHANGE_ID_FIELD_NUMBER: builtins.int
        UNDERLYING_ISIN_FIELD_NUMBER: builtins.int
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        REQUIRE_TOTAL_FIELD_NUMBER: builtins.int
        SORT_COLUMNS_FIELD_NUMBER: builtins.int
        SORT_TYPES_FIELD_NUMBER: builtins.int
        future_exchange_id: builtins.int = ...
        underlying_isin: typing.Text = ...
        search_text: typing.Text = ...
        offset: builtins.int = ...
        limit: builtins.int = ...
        require_total: builtins.bool = ...
        sort_columns: typing.Text = ...
        sort_types: typing.Text = ...
        def __init__(self,
            *,
            future_exchange_id : builtins.int = ...,
            underlying_isin : typing.Text = ...,
            search_text : typing.Text = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            require_total : builtins.bool = ...,
            sort_columns : typing.Text = ...,
            sort_types : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"future_exchange_id",b"future_exchange_id",u"limit",b"limit",u"offset",b"offset",u"require_total",b"require_total",u"search_text",b"search_text",u"sort_columns",b"sort_columns",u"sort_types",b"sort_types",u"underlying_isin",b"underlying_isin"]) -> None: ...

    class RequestLeverageds(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        POPULAR_ONLY_FIELD_NUMBER: builtins.int
        INPUT_AGGREGATE_TYPES_FIELD_NUMBER: builtins.int
        INPUT_AGGREGATE_VALUES_FIELD_NUMBER: builtins.int
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        REQUIRE_TOTAL_FIELD_NUMBER: builtins.int
        SORT_COLUMNS_FIELD_NUMBER: builtins.int
        SORT_TYPES_FIELD_NUMBER: builtins.int
        popular_only: builtins.bool = ...
        input_aggregate_types: typing.Text = ...
        input_aggregate_values: typing.Text = ...
        search_text: typing.Text = ...
        offset: builtins.int = ...
        limit: builtins.int = ...
        require_total: builtins.bool = ...
        sort_columns: typing.Text = ...
        sort_types: typing.Text = ...
        def __init__(self,
            *,
            popular_only : builtins.bool = ...,
            input_aggregate_types : typing.Text = ...,
            input_aggregate_values : typing.Text = ...,
            search_text : typing.Text = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            require_total : builtins.bool = ...,
            sort_columns : typing.Text = ...,
            sort_types : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"input_aggregate_types",b"input_aggregate_types",u"input_aggregate_values",b"input_aggregate_values",u"limit",b"limit",u"offset",b"offset",u"popular_only",b"popular_only",u"require_total",b"require_total",u"search_text",b"search_text",u"sort_columns",b"sort_columns",u"sort_types",b"sort_types"]) -> None: ...

    class RequestLookup(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        PRODUCT_TYPE_ID_FIELD_NUMBER: builtins.int
        search_text: typing.Text = ...
        limit: builtins.int = ...
        offset: builtins.int = ...
        product_type_id: builtins.int = ...
        def __init__(self,
            *,
            search_text : typing.Text = ...,
            limit : builtins.int = ...,
            offset : builtins.int = ...,
            product_type_id : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"limit",b"limit",u"offset",b"offset",u"product_type_id",b"product_type_id",u"search_text",b"search_text"]) -> None: ...

    class RequestOptions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        INPUT_AGGREGATE_TYPES_FIELD_NUMBER: builtins.int
        INPUT_AGGREGATE_VALUES_FIELD_NUMBER: builtins.int
        OPTION_EXCHANGE_ID_FIELD_NUMBER: builtins.int
        UNDERLYING_ISIN_FIELD_NUMBER: builtins.int
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        REQUIRE_TOTAL_FIELD_NUMBER: builtins.int
        SORT_COLUMNS_FIELD_NUMBER: builtins.int
        SORT_TYPES_FIELD_NUMBER: builtins.int
        input_aggregate_types: typing.Text = ...
        input_aggregate_values: typing.Text = ...
        option_exchange_id: builtins.int = ...
        underlying_isin: typing.Text = ...
        search_text: typing.Text = ...
        offset: builtins.int = ...
        limit: builtins.int = ...
        require_total: builtins.bool = ...
        sort_columns: typing.Text = ...
        sort_types: typing.Text = ...
        def __init__(self,
            *,
            input_aggregate_types : typing.Text = ...,
            input_aggregate_values : typing.Text = ...,
            option_exchange_id : builtins.int = ...,
            underlying_isin : typing.Text = ...,
            search_text : typing.Text = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            require_total : builtins.bool = ...,
            sort_columns : typing.Text = ...,
            sort_types : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"input_aggregate_types",b"input_aggregate_types",u"input_aggregate_values",b"input_aggregate_values",u"limit",b"limit",u"offset",b"offset",u"option_exchange_id",b"option_exchange_id",u"require_total",b"require_total",u"search_text",b"search_text",u"sort_columns",b"sort_columns",u"sort_types",b"sort_types",u"underlying_isin",b"underlying_isin"]) -> None: ...

    class RequestStocks(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        IS_IN_US_GREEN_LIST_FIELD_NUMBER: builtins.int
        INDEX_ID_FIELD_NUMBER: builtins.int
        EXCHANGE_ID_FIELD_NUMBER: builtins.int
        STOCK_COUNTRY_ID_FIELD_NUMBER: builtins.int
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        REQUIRE_TOTAL_FIELD_NUMBER: builtins.int
        SORT_COLUMNS_FIELD_NUMBER: builtins.int
        SORT_TYPES_FIELD_NUMBER: builtins.int
        is_in_us_green_list: builtins.bool = ...
        index_id: builtins.int = ...
        exchange_id: builtins.int = ...
        stock_country_id: builtins.int = ...
        search_text: typing.Text = ...
        offset: builtins.int = ...
        limit: builtins.int = ...
        require_total: builtins.bool = ...
        sort_columns: typing.Text = ...
        sort_types: typing.Text = ...
        def __init__(self,
            *,
            is_in_us_green_list : builtins.bool = ...,
            index_id : builtins.int = ...,
            exchange_id : builtins.int = ...,
            stock_country_id : builtins.int = ...,
            search_text : typing.Text = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            require_total : builtins.bool = ...,
            sort_columns : typing.Text = ...,
            sort_types : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"exchange_id",b"exchange_id",u"index_id",b"index_id",u"is_in_us_green_list",b"is_in_us_green_list",u"limit",b"limit",u"offset",b"offset",u"require_total",b"require_total",u"search_text",b"search_text",u"sort_columns",b"sort_columns",u"sort_types",b"sort_types",u"stock_country_id",b"stock_country_id"]) -> None: ...

    class RequestWarrants(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        SEARCH_TEXT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        REQUIRE_TOTAL_FIELD_NUMBER: builtins.int
        SORT_COLUMNS_FIELD_NUMBER: builtins.int
        SORT_TYPES_FIELD_NUMBER: builtins.int
        search_text: typing.Text = ...
        offset: builtins.int = ...
        limit: builtins.int = ...
        require_total: builtins.bool = ...
        sort_columns: typing.Text = ...
        sort_types: typing.Text = ...
        def __init__(self,
            *,
            search_text : typing.Text = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            require_total : builtins.bool = ...,
            sort_columns : typing.Text = ...,
            sort_types : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"limit",b"limit",u"offset",b"offset",u"require_total",b"require_total",u"search_text",b"search_text",u"sort_columns",b"sort_columns",u"sort_types",b"sort_types"]) -> None: ...

    OFFSET_FIELD_NUMBER: builtins.int
    PRODUCTS_FIELD_NUMBER: builtins.int
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    offset: builtins.int = ...
    """PROPERTIES"""

    @property
    def products(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    total: builtins.int = ...
    def __init__(self,
        *,
        offset : builtins.int = ...,
        products : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        total : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"offset",b"offset",u"products",b"products",u"response_datetime",b"response_datetime",u"total",b"total"]) -> None: ...
global___ProductSearch = ProductSearch

class Favourites(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/pa/secure/favourites/lists
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class List(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ID_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        IS_DEFAULT_FIELD_NUMBER: builtins.int
        PRODUCT_IDS_FIELD_NUMBER: builtins.int
        id: builtins.int = ...
        """PROPERTIES"""

        name: typing.Text = ...
        is_default: builtins.bool = ...
        @property
        def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
        def __init__(self,
            *,
            id : builtins.int = ...,
            name : typing.Text = ...,
            is_default : builtins.bool = ...,
            product_ids : typing.Optional[typing.Iterable[builtins.int]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"id",b"id",u"is_default",b"is_default",u"name",b"name",u"product_ids",b"product_ids"]) -> None: ...

    VALUES_FIELD_NUMBER: builtins.int
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Favourites.List]:
        """PROPERTIES"""
        pass
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        values : typing.Optional[typing.Iterable[global___Favourites.List]] = ...,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime",u"values",b"values"]) -> None: ...
global___Favourites = Favourites

class ProductsInfo(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/product_search/secure/v5/products/info
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        PRODUCTS_FIELD_NUMBER: builtins.int
        @property
        def products(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
            """PROPERTIES"""
            pass
        def __init__(self,
            *,
            products : typing.Optional[typing.Iterable[builtins.int]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"products",b"products"]) -> None: ...

    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.struct_pb2.Struct:
        """PROPERTIES"""
        pass
    def __init__(self,
        *,
        values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> None: ...
global___ProductsInfo = ProductsInfo

class CompanyRatios(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/dgtbxdsservice/company-ratios
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.struct_pb2.Struct:
        """PROPERTIES"""
        pass
    def __init__(self,
        *,
        values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> None: ...
global___CompanyRatios = CompanyRatios

class CompanyProfile(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/dgtbxdsservice/company-profile/v2
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.struct_pb2.Struct:
        """PROPERTIES"""
        pass
    def __init__(self,
        *,
        values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> None: ...
global___CompanyProfile = CompanyProfile

class FinancialStatements(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/dgtbxdsservice/financial-statements
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.struct_pb2.Struct:
        """PROPERTIES"""
        pass
    def __init__(self,
        *,
        values : typing.Optional[google.protobuf.struct_pb2.Struct] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"values",b"values"]) -> None: ...
global___FinancialStatements = FinancialStatements

class LatestNews(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/dgtbxdsservice/newsfeed/v2/latest-news
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        OFFSET_FIELD_NUMBER: builtins.int
        LANGUAGES_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        offset: builtins.int = ...
        """PROPERTIES"""

        languages: typing.Text = ...
        limit: builtins.int = ...
        def __init__(self,
            *,
            offset : builtins.int = ...,
            languages : typing.Text = ...,
            limit : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"languages",b"languages",u"limit",b"limit",u"offset",b"offset"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """PROPERTIES"""
        pass
    offset: builtins.int = ...
    total: builtins.int = ...
    def __init__(self,
        *,
        items : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        offset : builtins.int = ...,
        total : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"items",b"items",u"offset",b"offset",u"total",b"total"]) -> None: ...
global___LatestNews = LatestNews

class TopNewsPreview(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/dgtbxdsservice/newsfeed/v2/top-news-preview
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """PROPERTIES"""
        pass
    offset: builtins.int = ...
    total: builtins.int = ...
    def __init__(self,
        *,
        items : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        offset : builtins.int = ...,
        total : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"items",b"items",u"offset",b"offset",u"total",b"total"]) -> None: ...
global___TopNewsPreview = TopNewsPreview

class NewsByCompany(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/dgtbxdsservice/newsfeed/v2/news-by-company
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ISIN_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LANGUAGES_FIELD_NUMBER: builtins.int
        isin: typing.Text = ...
        """PROPERTIES"""

        limit: builtins.int = ...
        offset: builtins.int = ...
        languages: typing.Text = ...
        def __init__(self,
            *,
            isin : typing.Text = ...,
            limit : builtins.int = ...,
            offset : builtins.int = ...,
            languages : typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"isin",b"isin",u"languages",b"languages",u"limit",b"limit",u"offset",b"offset"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """PROPERTIES"""
        pass
    offset: builtins.int = ...
    total: builtins.int = ...
    def __init__(self,
        *,
        items : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        offset : builtins.int = ...,
        total : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"items",b"items",u"offset",b"offset",u"total",b"total"]) -> None: ...
global___NewsByCompany = NewsByCompany

class CashAccountReport(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/reporting/secure/v3/cashAccountReport
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Format(_Format, metaclass=_FormatEnumTypeWrapper):
        """ENUMS"""
        pass
    class _Format:
        V = typing.NewType('V', builtins.int)
    class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Format.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        CSV = CashAccountReport.Format.V(0)
        HTML = CashAccountReport.Format.V(1)
        PDF = CashAccountReport.Format.V(2)
        XLS = CashAccountReport.Format.V(3)

    CSV = CashAccountReport.Format.V(0)
    HTML = CashAccountReport.Format.V(1)
    PDF = CashAccountReport.Format.V(2)
    XLS = CashAccountReport.Format.V(3)

    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Date(google.protobuf.message.Message):
            """MESSAGES"""
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            YEAR_FIELD_NUMBER: builtins.int
            MONTH_FIELD_NUMBER: builtins.int
            DAY_FIELD_NUMBER: builtins.int
            year: builtins.int = ...
            month: builtins.int = ...
            day: builtins.int = ...
            def __init__(self,
                *,
                year : builtins.int = ...,
                month : builtins.int = ...,
                day : builtins.int = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"day",b"day",u"month",b"month",u"year",b"year"]) -> None: ...

        FORMAT_FIELD_NUMBER: builtins.int
        COUNTRY_FIELD_NUMBER: builtins.int
        LANG_FIELD_NUMBER: builtins.int
        FROM_DATE_FIELD_NUMBER: builtins.int
        TO_DATE_FIELD_NUMBER: builtins.int
        format: global___CashAccountReport.Format.V = ...
        """PROPERTIES"""

        country: typing.Text = ...
        lang: typing.Text = ...
        @property
        def from_date(self) -> global___CashAccountReport.Request.Date: ...
        @property
        def to_date(self) -> global___CashAccountReport.Request.Date: ...
        def __init__(self,
            *,
            format : global___CashAccountReport.Format.V = ...,
            country : typing.Text = ...,
            lang : typing.Text = ...,
            from_date : typing.Optional[global___CashAccountReport.Request.Date] = ...,
            to_date : typing.Optional[global___CashAccountReport.Request.Date] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"from_date",b"from_date",u"to_date",b"to_date"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"country",b"country",u"format",b"format",u"from_date",b"from_date",u"lang",b"lang",u"to_date",b"to_date"]) -> None: ...

    CONTENT_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    content: typing.Text = ...
    """PROPERTIES"""

    format: global___CashAccountReport.Format.V = ...
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        content : typing.Text = ...,
        format : global___CashAccountReport.Format.V = ...,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content",b"content",u"format",b"format",u"response_datetime",b"response_datetime"]) -> None: ...
global___CashAccountReport = CashAccountReport

class Agenda(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/dgtbxdsservice/agenda/v2
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class CalendarType(_CalendarType, metaclass=_CalendarTypeEnumTypeWrapper):
        """ENUMS"""
        pass
    class _CalendarType:
        V = typing.NewType('V', builtins.int)
    class _CalendarTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CalendarType.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        DIVIDEND_CALENDAR = Agenda.CalendarType.V(0)
        ECONOMIC_CALENDAR = Agenda.CalendarType.V(1)
        EARNINGS_CALENDAR = Agenda.CalendarType.V(2)
        HOLIDAY_CALENDAR = Agenda.CalendarType.V(3)
        IPO_CALENDAR = Agenda.CalendarType.V(4)
        SPLIT_CALENDAR = Agenda.CalendarType.V(5)

    DIVIDEND_CALENDAR = Agenda.CalendarType.V(0)
    ECONOMIC_CALENDAR = Agenda.CalendarType.V(1)
    EARNINGS_CALENDAR = Agenda.CalendarType.V(2)
    HOLIDAY_CALENDAR = Agenda.CalendarType.V(3)
    IPO_CALENDAR = Agenda.CalendarType.V(4)
    SPLIT_CALENDAR = Agenda.CalendarType.V(5)

    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CALENDAR_TYPE_FIELD_NUMBER: builtins.int
        OFFSET_FIELD_NUMBER: builtins.int
        LIMIT_FIELD_NUMBER: builtins.int
        ORDER_BY_DESC_FIELD_NUMBER: builtins.int
        START_DATE_FIELD_NUMBER: builtins.int
        END_DATE_FIELD_NUMBER: builtins.int
        COMPANY_NAME_FIELD_NUMBER: builtins.int
        COUNTRIES_FIELD_NUMBER: builtins.int
        CLASSIFICATIONS_FIELD_NUMBER: builtins.int
        UNITS_FIELD_NUMBER: builtins.int
        calendar_type: global___Agenda.CalendarType.V = ...
        """PROPERTIES"""

        offset: builtins.int = ...
        limit: builtins.int = ...
        order_by_desc: builtins.bool = ...
        @property
        def start_date(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        @property
        def end_date(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        company_name: typing.Text = ...
        countries: typing.Text = ...
        classifications: typing.Text = ...
        units: typing.Text = ...
        def __init__(self,
            *,
            calendar_type : global___Agenda.CalendarType.V = ...,
            offset : builtins.int = ...,
            limit : builtins.int = ...,
            order_by_desc : builtins.bool = ...,
            start_date : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
            end_date : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
            company_name : typing.Text = ...,
            countries : typing.Text = ...,
            classifications : typing.Text = ...,
            units : typing.Text = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"end_date",b"end_date",u"start_date",b"start_date"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"calendar_type",b"calendar_type",u"classifications",b"classifications",u"company_name",b"company_name",u"countries",b"countries",u"end_date",b"end_date",u"limit",b"limit",u"offset",b"offset",u"order_by_desc",b"order_by_desc",u"start_date",b"start_date",u"units",b"units"]) -> None: ...

    CALENDAR_TYPE_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    calendar_type: global___Agenda.CalendarType.V = ...
    """PROPERTIES"""

    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
    offset: builtins.int = ...
    total: builtins.int = ...
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        calendar_type : global___Agenda.CalendarType.V = ...,
        items : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        offset : builtins.int = ...,
        total : builtins.int = ...,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"calendar_type",b"calendar_type",u"items",b"items",u"offset",b"offset",u"response_datetime",b"response_datetime",u"total",b"total"]) -> None: ...
global___Agenda = Agenda

class EstimatesSummaries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ANNUAL_FIELD_NUMBER: builtins.int
    CURRENCY_FIELD_NUMBER: builtins.int
    INTERIM_FIELD_NUMBER: builtins.int
    LASTRETRIEVED_FIELD_NUMBER: builtins.int
    LASTUPDATED_FIELD_NUMBER: builtins.int
    PREFERREDMEASURE_FIELD_NUMBER: builtins.int
    RIC_FIELD_NUMBER: builtins.int
    @property
    def annual(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """PROPERTIES"""
        pass
    currency: typing.Text = ...
    @property
    def interim(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]: ...
    lastRetrieved: typing.Text = ...
    lastUpdated: typing.Text = ...
    preferredMeasure: typing.Text = ...
    ric: typing.Text = ...
    def __init__(self,
        *,
        annual : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        currency : typing.Text = ...,
        interim : typing.Optional[typing.Iterable[google.protobuf.struct_pb2.Struct]] = ...,
        lastRetrieved : typing.Text = ...,
        lastUpdated : typing.Text = ...,
        preferredMeasure : typing.Text = ...,
        ric : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"annual",b"annual",u"currency",b"currency",u"interim",b"interim",u"lastRetrieved",b"lastRetrieved",u"lastUpdated",b"lastUpdated",u"preferredMeasure",b"preferredMeasure",u"ric",b"ric"]) -> None: ...
global___EstimatesSummaries = EstimatesSummaries

class PositionReport(google.protobuf.message.Message):
    """* For the payload from the following URL :
    https://trader.degiro.nl/reporting/secure/v3/positionReport
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Format(_Format, metaclass=_FormatEnumTypeWrapper):
        """ENUMS"""
        pass
    class _Format:
        V = typing.NewType('V', builtins.int)
    class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Format.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        CSV = PositionReport.Format.V(0)
        HTML = PositionReport.Format.V(1)
        PDF = PositionReport.Format.V(2)
        XLS = PositionReport.Format.V(3)

    CSV = PositionReport.Format.V(0)
    HTML = PositionReport.Format.V(1)
    PDF = PositionReport.Format.V(2)
    XLS = PositionReport.Format.V(3)

    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Date(google.protobuf.message.Message):
            """MESSAGES"""
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            YEAR_FIELD_NUMBER: builtins.int
            MONTH_FIELD_NUMBER: builtins.int
            DAY_FIELD_NUMBER: builtins.int
            year: builtins.int = ...
            month: builtins.int = ...
            day: builtins.int = ...
            def __init__(self,
                *,
                year : builtins.int = ...,
                month : builtins.int = ...,
                day : builtins.int = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"day",b"day",u"month",b"month",u"year",b"year"]) -> None: ...

        FORMAT_FIELD_NUMBER: builtins.int
        COUNTRY_FIELD_NUMBER: builtins.int
        LANG_FIELD_NUMBER: builtins.int
        TO_DATE_FIELD_NUMBER: builtins.int
        format: global___PositionReport.Format.V = ...
        """PROPERTIES"""

        country: typing.Text = ...
        lang: typing.Text = ...
        @property
        def to_date(self) -> global___PositionReport.Request.Date: ...
        def __init__(self,
            *,
            format : global___PositionReport.Format.V = ...,
            country : typing.Text = ...,
            lang : typing.Text = ...,
            to_date : typing.Optional[global___PositionReport.Request.Date] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"to_date",b"to_date"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"country",b"country",u"format",b"format",u"lang",b"lang",u"to_date",b"to_date"]) -> None: ...

    CONTENT_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    content: typing.Text = ...
    """PROPERTIES"""

    format: global___PositionReport.Format.V = ...
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        content : typing.Text = ...,
        format : global___PositionReport.Format.V = ...,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content",b"content",u"format",b"format",u"response_datetime",b"response_datetime"]) -> None: ...
global___PositionReport = PositionReport
